@@ -298,28 +298,36 @@ fn inner_test_seal_proof_aggregation_2kib_porep_id_v1_1_base_8(
     let mut commit_outputs = Vec::with_capacity(proofs_to_aggregate);
     let mut commit_inputs = Vec::with_capacity(proofs_to_aggregate);
     let mut seeds = Vec::with_capacity(proofs_to_aggregate);
+    let mut comm_rs = Vec::with_capacity(proofs_to_aggregate);
 
-    let (commit_output, commit_input, seed) = create_seal_for_aggregation::<_, SectorShape2KiB>(
-        rng,
-        SECTOR_SIZE_2_KIB,
-        prover_id,
-        &porep_id,
-        ApiVersion::V1_1_0,
-    )?;
+    let (commit_output, commit_input, seed, comm_r) =
+        create_seal_for_aggregation::<_, SectorShape2KiB>(
+            rng,
+            SECTOR_SIZE_2_KIB,
+            prover_id,
+            &porep_id,
+            ApiVersion::V1_1_0,
+        )?;
 
     // duplicate a single proof to desired target for aggregation
     for _ in 0..proofs_to_aggregate {
         commit_outputs.push(commit_output.clone());
         commit_inputs.extend(commit_input.clone());
         seeds.push(seed);
+        comm_rs.push(comm_r);
     }
 
     let config = porep_config(SECTOR_SIZE_2_KIB, porep_id, ApiVersion::V1_1_0);
-    let aggregate_proof =
-        aggregate_seal_commit_proofs::<SectorShape2KiB>(config, &seeds, commit_outputs.as_slice())?;
+    let aggregate_proof = aggregate_seal_commit_proofs::<SectorShape2KiB>(
+        config,
+        &comm_rs,
+        &seeds,
+        commit_outputs.as_slice(),
+    )?;
     let verified = verify_aggregate_seal_commit_proofs::<SectorShape2KiB>(
         config,
         aggregate_proof,
+        &comm_rs,
         &seeds,
         commit_inputs,
     )?;
@@ -342,8 +350,10 @@ fn aggregate_proofs<Tree: 'static + MerkleTreeTrait>(
     let mut commit_outputs = Vec::with_capacity(num_proofs_to_aggregate);
     let mut commit_inputs = Vec::with_capacity(num_proofs_to_aggregate);
     let mut seeds = Vec::with_capacity(num_proofs_to_aggregate);
+    let mut comm_rs = Vec::with_capacity(num_proofs_to_aggregate);
+
     for _ in 0..num_proofs_to_aggregate {
-        let (commit_output, commit_input, seed) = create_seal_for_aggregation::<_, Tree>(
+        let (commit_output, commit_input, seed, comm_r) = create_seal_for_aggregation::<_, Tree>(
             rng,
             sector_size,
             prover_id,
@@ -353,17 +363,24 @@ fn aggregate_proofs<Tree: 'static + MerkleTreeTrait>(
         commit_outputs.push(commit_output);
         commit_inputs.extend(commit_input);
         seeds.push(seed);
+        comm_rs.push(comm_r);
     }
 
     let config = porep_config(sector_size, *porep_id, api_version);
     let aggregate_proof =
-        aggregate_seal_commit_proofs::<Tree>(config, &seeds, commit_outputs.as_slice())?;
-    verify_aggregate_seal_commit_proofs::<Tree>(config, aggregate_proof, &seeds, commit_inputs)
+        aggregate_seal_commit_proofs::<Tree>(config, &comm_rs, &seeds, commit_outputs.as_slice())?;
+    verify_aggregate_seal_commit_proofs::<Tree>(
+        config,
+        aggregate_proof,
+        &comm_rs,
+        &seeds,
+        commit_inputs,
+    )
 }
 
 fn get_layer_file_paths(cache_dir: &tempfile::TempDir) -> Vec<PathBuf> {
     let mut list: Vec<_> = read_dir(&cache_dir)
-        .expect(&format!("failed to read directory {:?}", cache_dir))
+        .unwrap_or_else(|_| panic!("failed to read directory {:?}", cache_dir))
         .filter_map(|entry| {
             let cur = entry.expect("reading directory failed");
             let entry_path = cur.path();
@@ -694,12 +711,8 @@ fn winning_post<Tree: 'static + MerkleTreeTrait>(
     //
     // 2)
     let mut vanilla_proofs = Vec::with_capacity(sector_count);
-    let challenges = generate_fallback_sector_challenges::<Tree>(
-        &config,
-        &randomness,
-        &vec![sector_id],
-        prover_id,
-    )?;
+    let challenges =
+        generate_fallback_sector_challenges::<Tree>(&config, &randomness, &[sector_id], prover_id)?;
 
     let single_proof = generate_single_vanilla_proof::<Tree>(
         &config,
@@ -1173,6 +1186,7 @@ fn run_seal_pre_commit_phase1<Tree: 'static + MerkleTreeTrait>(
     Ok((piece_infos, phase1_output))
 }
 
+#[allow(clippy::too_many_arguments)]
 fn generate_proof<Tree: 'static + MerkleTreeTrait>(
     config: PoRepConfig,
     cache_dir_path: &Path,
@@ -1183,7 +1197,7 @@ fn generate_proof<Tree: 'static + MerkleTreeTrait>(
     seed: [u8; 32],
     pre_commit_output: &SealPreCommitOutput,
     piece_infos: &[PieceInfo],
-) -> Result<(SealCommitOutput, Vec<Vec<Fr>>, [u8; 32])> {
+) -> Result<(SealCommitOutput, Vec<Vec<Fr>>, [u8; 32], [u8; 32])> {
     let phase1_output = seal_commit_phase1::<_, Tree>(
         config,
         cache_dir_path,
@@ -1207,6 +1221,7 @@ fn generate_proof<Tree: 'static + MerkleTreeTrait>(
         "seed and phase1 output ticket do not match"
     );
 
+    let comm_r = phase1_output.comm_r;
     let inputs = get_seal_inputs::<Tree>(
         config,
         phase1_output.comm_r,
@@ -1218,9 +1233,10 @@ fn generate_proof<Tree: 'static + MerkleTreeTrait>(
     )?;
     let result = seal_commit_phase2(config, phase1_output, prover_id, sector_id)?;
 
-    Ok((result, inputs, seed))
+    Ok((result, inputs, seed, comm_r))
 }
 
+#[allow(clippy::too_many_arguments)]
 fn unseal<Tree: 'static + MerkleTreeTrait>(
     config: PoRepConfig,
     cache_dir_path: &Path,
@@ -1282,6 +1298,7 @@ fn unseal<Tree: 'static + MerkleTreeTrait>(
     Ok(())
 }
 
+#[allow(clippy::too_many_arguments)]
 fn proof_and_unseal<Tree: 'static + MerkleTreeTrait>(
     config: PoRepConfig,
     cache_dir_path: &Path,
@@ -1294,7 +1311,7 @@ fn proof_and_unseal<Tree: 'static + MerkleTreeTrait>(
     piece_infos: &[PieceInfo],
     piece_bytes: &[u8],
 ) -> Result<()> {
-    let (commit_output, _commit_inputs, _seed) = generate_proof::<Tree>(
+    let (commit_output, _commit_inputs, _seed, _comm_r) = generate_proof::<Tree>(
         config,
         cache_dir_path,
         sealed_sector_file,
@@ -1388,7 +1405,7 @@ fn create_seal_for_aggregation<R: Rng, Tree: 'static + MerkleTreeTrait>(
     prover_id: ProverId,
     porep_id: &[u8; 32],
     api_version: ApiVersion,
-) -> Result<(SealCommitOutput, Vec<Vec<Fr>>, [u8; 32])> {
+) -> Result<(SealCommitOutput, Vec<Vec<Fr>>, [u8; 32], [u8; 32])> {
     init_logger();
 
     let (mut piece_file, _piece_bytes) = generate_piece_file(sector_size)?;
